package jlowplugin.ui;

import javax.swing.*;
import java.awt.*;

import java.awt.event.*;


/***
 * Menu de l'application. 
 * Implemente des methodes avancees qui peuvent etre utilise afin de manipuler le menu.
 */
public abstract class AbstractMenu extends JMenuBar {

    
    /**Attributs**/
    //private static Color CBG = SystemColor.menu;
    //private static Color CFG = SystemColor.menuText;

    /**Composants Graphiques**/
    protected JFrame mainFrame;

    /**Constructeurs**/
    /**
     * Constructeur de la classe Menu. Cette classe est generalement instancee dans la classe de la fenetre principale.
     * @param f Fenetre principale dans laquelle le menu va etre afficher.
     */
    public AbstractMenu(JFrame f) { 		
	//cFont = Color.BLACK;
	//cTexte = Color.WHITE;
	
	//setBackground(MenuJ.CBG);
	//setForeground(MenuJ.CFG);
	
	mainFrame = f;
	
	//createMenu();
 		
    }
    

    //Methodes
    
    /**
     * Retourne l'item ayant la position <i>posItem</i> dans le menu de position <i>posMenu</i>.
     * @param posMenu Position du menu.
     * @param posItem Position de l'item.
     * @return L'item correspondant.
     */
    public JMenuItem getItem(int posMenu, int posItem) {

	return getMenu(posMenu).getItem(posItem);
    }
    
    /**
     * Retourne l'index du menu
     */
    /*
    public JMenu getIndexMenu(String menu) {
	return getMenu(posMenu);
    }
    */
    //Modificateurs

    //Autres methodes
    //Methodes statiques
    /**
     * Insertion d'un item descrit par les parametres passes en entree de fonction dans le menu voulu.
     * @param posItem Position de l'item dans le menu.
     * @param item Nom de l'item.
     * @param accel Accelerateur de l'item. (Voir <i>MenuItem</i>)
     * @param mne Mnemonic de l'item. (Voir <i>MenuItem</i>)
     * @param acces Accessible de l'item. (Voir <i>MenuItem</i>)
     * @param al Ecouteur de l'item. (Voir <i>MenuItem</i>)
     * @param ma Ecouteur souris de l'item. (Voir <i>MenuItem</i>)
     */
    public static void insert(JMenu m, int posItem, String item, String accel, String mne, String acces, ActionListener al, MouseAdapter ma) {
	


	if(item.equals("|"))
	    m.add(new JSeparator(), posItem);
	else {
	    
	    JMenuItem i = new JMenuItem(item);
	    
	    //i.setBackground(MenuJ.CBG);
	    //i.setForeground(MenuJ.CFG);
	    //i.setFont(new Font("Helvetica",Font.PLAIN,14));
	    //i.addMouseListener(this);

	    if(mne!=null)
		i.setMnemonic(mne.charAt(0));
	    
	    if(accel!=null)
		i.setAccelerator(KeyStroke.getKeyStroke(accel));
	    
	    if(acces!=null)
		i.getAccessibleContext().setAccessibleDescription(acces);
	    
	    i.addMouseListener(ma);
	    
	    i.addActionListener(al);
	    
	    m.insert(i, posItem);
	}
    }


    /**
     * Insertion d'un sous menu descrit par les parametres passes en entree de fonction dans le menu voulu.
     * @param posItem Position de l'item dans le menu.
     * @param item Nom du sous menu.
     * @param accel Accelerateur de l'item. (Voir <i>MenuItem</i>)
     * @param mne Mnemonic de l'item. (Voir <i>MenuItem</i>)
     * @param acces Accessible de l'item. (Voir <i>MenuItem</i>)
     * @param ma Ecouteur souris de l'item. (Voir <i>MenuItem</i>)
     * @return Le sous menu creee.
     */
    public static JMenu insertSubMenu(JMenu m, int posItem, String item, String accel, String mne, String acces, MouseAdapter ma) {
	JMenu s = new JMenu(item);
	//s.setBackground(MenuJ.CBG);
	//s.setForeground(MenuJ.CFG);
	//s.setFont(new Font("Helvetica",Font.PLAIN,14));
	
	if(mne!=null)
	    s.setMnemonic(mne.charAt(0));
	
	if(acces!=null)
	    s.getAccessibleContext().setAccessibleDescription(acces);
	
	if(ma!=null)
	    s.addMouseListener(ma);
	
	m.insert(s, posItem);

	return s;
    }



    /***********************************************************/
    //Methode non static

    /**
     * Creation d'un menu et ajout a la fin.
     * @param name Nom du menu.
     * @param mne Mnemonic du menu.
     */
    public JMenu addMenu(String name, String mne) {
	int pos = getMenuCount();
	return addMenu(name, mne, pos);
    }

    /**
     * Insertion d'un menu a une position donnees.
     * @param name Nom du menu.
     * @param mne Mnemonic du menu.
     * @param pos Position dans la barre de menu.
     */
    public JMenu addMenu(String name, String mne, int pos) {
	JMenu m = new JMenu(name);

	//m.setBackground(MenuJ.CBG);
	//m.setForeground(MenuJ.CFG);
	//m.setFont(new Font("Helvetica",Font.PLAIN,14));

	if(mne!=null)
	    m.setMnemonic(mne.charAt(0));

	add(m,pos);
	return m;
    }
	
	/**
	 * Returns a menu in a specify menu bar.
	 * @param menubar a menu bar
	 * @param name the name of a menu (method <code>getText</code>)
	 * @return the menu in the specify menu bar, Null if it not found
	 */
	public static JMenu getMenu(JMenuBar menubar, String name) {
		int menucount = menubar.getMenuCount();
		for(int i=0;i<menucount;i++) {
			JMenu menu = menubar.getMenu(i);
			
			if(menu.getText().equals(name))
				return menu;
		}
		return null;
	}

	public static JMenuItem getItem(JMenu menu, String name) {
		int itemcount = menu.getItemCount();
		for(int i=0;i<itemcount;i++) {
			JMenuItem item = menu.getItem(i);
			
			if(item!=null && item.getText().equals(name))
				return item;
		}
		return null;
			
	}

    /**
     * Insertion de l'item <i>i</i> a la position <i>posItem</i> du menu <i>posMenu</i>.
     * @param posMenu Position du menu dans la barre de menu.
     * @param posItem Position de l'item dans le menu.
     * @param i Composante a inserer.
     */
    public void insert(int posMenu, int posItem, Component i) {
	JMenu m = getMenu(posMenu);
	
	//m.setBackground(MenuJ.CBG);
	//m.setForeground(MenuJ.CFG);
	//m.setFont(new Font("Helvetica",Font.PLAIN,14));

	m.add(i,posItem);
    }


    public void insertSeparator(int posMenu, int posItem) {
	insert(posMenu, posItem, new JSeparator());
    }


    /**
     * Insertion d'un item descrit par les parametres passes en entree de fonction.
     * @param posMenu Position du menu dans la barre de menu.
     * @param posItem Position de l'item dans le menu.
     * @param item Nom de l'item.
     * @param accel Accelerateur de l'item. (Voir <i>MenuItem</i>)
     * @param mne Mnemonic de l'item. (Voir <i>MenuItem</i>)
     * @param acces Accessible de l'item. (Voir <i>MenuItem</i>)
     * @param al Ecouteur de l'item. (Voir <i>MenuItem</i>)
     * @param ma Ecouteur souris de l'item. (Voir <i>MenuItem</i>)

     */
    public JMenuItem insert(int posMenu, int posItem, String item, String accel, String mne, String acces, ActionListener al, MouseAdapter ma) {
	
	JMenuItem i = null;
	
	i = new JMenuItem(item);
	//i.setBackground(MenuJ.CBG);
	//i.setForeground(MenuJ.CFG);
	//i.setFont(new Font("Helvetica",Font.PLAIN,14));
	//i.addMouseListener(this);
	
	if(mne!=null)
	    i.setMnemonic(mne.charAt(0));
	
	if(accel!=null)
	    i.setAccelerator(KeyStroke.getKeyStroke(accel));
	    
	if(acces!=null)
	    i.getAccessibleContext().setAccessibleDescription(acces);
	
	i.addMouseListener(ma);
	
	i.addActionListener(al);
	
	insert(posMenu, posItem, i);
	
	return i;
    }
    
    
    

    /**
     * Insertion d'un sous menu descrit par les parametres passes en entree de fonction.
     * @param posMenu Position du menu dans la barre de menu.
     * @param posItem Position de l'item dans le menu.
     * @param item Nom du sous menu.
     * @param accel Accelerateur de l'item. (Voir <i>MenuItem</i>)
     * @param mne Mnemonic de l'item. (Voir <i>MenuItem</i>)
     * @param acces Accessible de l'item. (Voir <i>MenuItem</i>)
     * @param ma Ecouteur souris de l'item. (Voir <i>MenuItem</i>)
     * @return Le sous menu creee.
     */
    public JMenu insertSubMenu(int posMenu, int posItem, String item, String accel, String mne, String acces, MouseAdapter ma) {
	JMenu s = new JMenu(item);
	//s.setBackground(MenuJ.CBG);
	//s.setForeground(MenuJ.CFG);
	//s.setFont(new Font("Helvetica",Font.PLAIN,14));
	
	if(mne!=null)
	    s.setMnemonic(mne.charAt(0));
	
	if(acces!=null)
	    s.getAccessibleContext().setAccessibleDescription(acces);
	
	if(ma!=null)
	    s.addMouseListener(ma);
	
	insert(posMenu, posItem, s);

	return s;
    }


    
    public JMenu createSubMenu(String item, String accel, String mne, String acces, MouseAdapter ma) {
	JMenu s = new JMenu(item);
	//s.setBackground(MenuJ.CBG);
	//s.setForeground(MenuJ.CFG);
	//s.setFont(new Font("Helvetica",Font.PLAIN,14));
	
	if(mne!=null)
	    s.setMnemonic(mne.charAt(0));
	
	if(acces!=null)
	    s.getAccessibleContext().setAccessibleDescription(acces);
	
	if(ma!=null)
	    s.addMouseListener(ma);
	
	return s;
	}


    public static void setActionListener(JMenuItem m, ActionListener al) {
	
	m.addActionListener(al);
    }
}

